aboutsummaryrefslogtreecommitdiff
path: root/src/CamilStaps/BotleaguesApi/Database/User.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/CamilStaps/BotleaguesApi/Database/User.php')
-rw-r--r--src/CamilStaps/BotleaguesApi/Database/User.php14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/CamilStaps/BotleaguesApi/Database/User.php b/src/CamilStaps/BotleaguesApi/Database/User.php
index 383cc38..0af91c3 100644
--- a/src/CamilStaps/BotleaguesApi/Database/User.php
+++ b/src/CamilStaps/BotleaguesApi/Database/User.php
@@ -1,10 +1,14 @@
<?php
namespace CamilStaps\BotleaguesApi\Database;
-use Illuminate\Auth\Reminders\RemindableInterface;
-use Illuminate\Auth\UserInterface;
+use Illuminate\Auth\Authenticatable;
+use Illuminate\Auth\Passwords\CanResetPassword;
+use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;
+use Illuminate\Contracts\Auth\CanResetPassword as CanResetPasswordContract;
-class User extends Model implements UserInterface, RemindableInterface {
+class User extends Model implements AuthenticatableContract, CanResetPasswordContract {
+
+ use Authenticatable, CanResetPassword;
protected $table = 'users';
protected $hidden = ['password', 'remember_token', 'api_key'];
@@ -65,11 +69,11 @@ class User extends Model implements UserInterface, RemindableInterface {
}
/**
* Get the e-mail address where password reminders are sent.
*
* @return string
*/
- public function getReminderEmail() {
+ public function getEmailForPasswordReset() {
return $this->email;
}
} \ No newline at end of file
@@ -65,11 +69,11 @@ class User extends Model implements UserInterface, RemindableInterface {
}
/**
- * Get the e-mail address where password reminders are sent.
+ * Get the e-mail address where password reset links are sent.
*
* @return string